#' Additional items for the `usethis::use_release_issue()` function
#' @noRd
release_bullets <- function() {
  return(
    list(
      "Update the benchmarks"
    )
  )
}
